make_task

Function make_task 

pub fn make_task<F>(
    socket: TcpStream,
    response_handler: F,
    log: Option<&Logger>,
) -> impl Future<Item = (), Error = ()> + Send
Create a task to be used by the tokio runtime for handling responses to Fast protocol requests.