pub fn make_task<F>(
socket: TcpStream,
response_handler: F,
log: Option<&Logger>,
) -> impl Future<Item = (), Error = ()> + SendExpand description
Create a task to be used by the tokio runtime for handling responses to Fast protocol requests.